#ifndef __EVENTSOURCE_HH__
#define __EVENTSOURCE_HH__

#include <string>
#include <vector>
#include <istream>
#include <memory>
#include "fastjet/PseudoJet.hh"

//----------------------------------------------------------------------
/// \class EventSource
///
/// Class for reading events from a file (or stdin) in some simple format
class EventSource {
public:
  
  EventSource(const std::string & filename) {
    open_stream(filename);
  }

  /// set up an event stream from the corresponding file (in the PU14 format) 
  void open_stream(const std::string & filename);

  /// appends the particles from the next event that is read onto the 
  /// particles vector. Returns false if the next event could not be found
  bool append_next_event(std::vector<fastjet::PseudoJet> & particles,
                         int vertex_number = 0);

  /// fills the particles vector with the next event; returns true on
  /// success, false otherwise.
  bool next_event(std::vector<fastjet::PseudoJet> & particles) {
    particles.resize(0);
    return append_next_event(particles);
  }
private:
  std::istream * _stream;
  std::auto_ptr<std::istream> _stream_auto;

};
 
#endif // __EVENTSOURCE_HH__
